Transfer
================================

.. autoclass:: qbittorrentapi.transfer.TransferAPIMixIn
    :members:
    :undoc-members:
    :exclude-members: transfer, transfer_speedLimitsMode, transfer_toggleSpeedLimitsMode, transfer_downloadLimit, transfer_uploadLimit, transfer_setDownloadLimit, transfer_setUploadLimit, transfer_banPeers
    :show-inheritance:

.. autoclass:: qbittorrentapi.transfer.Transfer
    :members:
    :undoc-members:
    :exclude-members: toggleSpeedLimitsMode, setDownloadLimit, setUploadLimit, banPeers, speedLimitsMode, downloadLimit, uploadLimit, setSpeedLimitsMode

.. autoclass:: qbittorrentapi.transfer.TransferInfoDictionary
    :members:
    :undoc-members:
    :show-inheritance:
